| Title: | Toolkit for SRM-MS data (MS) data |
|---|---|
| Description: | A complete toolkit for working with Selective Reaction Monitoring (SRM) Mass Spectrometry (MS) data and other variants of targeted Liquid Chromatography (LC) MS data. |
| Authors: | Tom Wilson [aut, cre] |
| Maintainer: | Tom Wilson <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.6 |
| Built: | 2026-06-06 05:53:18 UTC |
| Source: | https://github.com/wilsontom/sRm |
Adjust Baseline
adjustBaseline(object, hwm) ## S4 method for signature 'SRM' adjustBaseline(object, hwm = 6)adjustBaseline(object, hwm) ## S4 method for signature 'SRM' adjustBaseline(object, hwm = 6)
object |
a SRM object |
hwm |
a numeric value for window half width for local medians |
a SRM object
Create peak group based on user specified retention time
createGroup(object, index, rt, width, id) ## S4 method for signature 'SRM' createGroup(object, index, rt, width, id)createGroup(object, index, rt, width, id) ## S4 method for signature 'SRM' createGroup(object, index, rt, width, id)
object |
a SRM object |
index |
a numeric value of the target transition index |
rt |
a numeric value of target Rt time (in minutes) |
width |
a numeric value of tolerated Rt width (in seconds) |
id |
a character string for peak group identification |
a SRM object
Detect Instrument Model
detectInstrumentModel(mzml_file)detectInstrumentModel(mzml_file)
mzml_file |
the absolute file path of a valid |
a character string of the MS cvParam description for the instrument model
Detect Peaks
detectPeaks(object, snthresh, peakwidth) ## S4 method for signature 'SRM' detectPeaks(object, snthresh, peakwidth)detectPeaks(object, snthresh, peakwidth) ## S4 method for signature 'SRM' detectPeaks(object, snthresh, peakwidth)
object |
a SRM object |
snthresh |
a numeric value for the signal-to-noise threshold to use |
peakwidth |
a numeric vector indicating the minimum and maximum tolerated peak width |
a SRM object
Extract a minimal amount meta data from a .mzML file
fileMetaData(x)fileMetaData(x)
x |
a valid |
a tibble containing;
mzML Schema
Acquisition Date
Acquisition Time
Instrument Model
File ID
Filter detected peaks based on a series of heuristic measures
filterPeaks(object) ## S4 method for signature 'SRM' filterPeaks(object)filterPeaks(object) ## S4 method for signature 'SRM' filterPeaks(object)
object |
a SRM object |
a SRM object
Allow free scales in facet plots
freeScales(ggplot)freeScales(ggplot)
ggplot |
a |
a ggplot object
Group detected peaks based on retention time. Based on MsCoreUtils::group
groupPeaks(object, rt_tolerance) ## S4 method for signature 'SRM' groupPeaks(object, rt_tolerance)groupPeaks(object, rt_tolerance) ## S4 method for signature 'SRM' groupPeaks(object, rt_tolerance)
object |
a SRM object |
rt_tolerance |
a numeric value for the tolerate retention grouping |
a SRM object
Create a summary table for peak groups
groupSummary(object) ## S4 method for signature 'SRM' groupSummary(object)groupSummary(object) ## S4 method for signature 'SRM' groupSummary(object)
object |
a |
a tibble of group summary
List object header information
header(object) ## S4 method for signature 'SRM' header(object)header(object) ## S4 method for signature 'SRM' header(object)
object |
a |
Find Target Retention Time (Rt) for a transition
indexRT(object, index, sampleName, n) ## S4 method for signature 'SRM' indexRT(object, index, sampleName, n = 1)indexRT(object, index, sampleName, n) ## S4 method for signature 'SRM' indexRT(object, index, sampleName, n = 1)
object |
a SRM object |
index |
a numeric value for the transition index |
sampleName |
a character string |
n |
a numeric value for the number of Rts to return (if > 1 is available) |
a numeric vector or Rt targets
Keep Transitions
keepTransitions(object, index_keep) ## S4 method for signature 'SRM' keepTransitions(object, index_keep = c())keepTransitions(object, index_keep) ## S4 method for signature 'SRM' keepTransitions(object, index_keep = c())
object |
a SRM object |
index_keep |
a numeric vector of transition index to retain |
a SRM object
List sample meta data
meta(object) ## S4 method for signature 'SRM' meta(object)meta(object) ## S4 method for signature 'SRM' meta(object)
object |
a |
Open and parse SRM files into an S4 SRM Object
openSRM(files)openSRM(files)
files |
a character vector of absolute file paths of SRM files in |
an SRM object
Peak Asymmetry
peakAsymmetry(object) ## S4 method for signature 'SRM' peakAsymmetry(object)peakAsymmetry(object) ## S4 method for signature 'SRM' peakAsymmetry(object)
object |
a SRM object |
a SRM object
List detected peaks
peaks(object) ## S4 method for signature 'SRM' peaks(object)peaks(object) ## S4 method for signature 'SRM' peaks(object)
object |
a |
Plot Group
plotGroup(object, group) ## S4 method for signature 'SRM' plotGroup(object, group)plotGroup(object, group) ## S4 method for signature 'SRM' plotGroup(object, group)
object |
a SRM object |
group |
a character string of the |
a ggplot plot object
Plot Parent
plotParent(object, parentMass) ## S4 method for signature 'SRM' plotParent(object, parentMass)plotParent(object, parentMass) ## S4 method for signature 'SRM' plotParent(object, parentMass)
object |
a SRM object |
parentMass |
a numeric value of the parent mass (Q1) to extract |
a ggplot plot object
Plot Peak Area
plotPeakArea(object, index, sampleName) ## S4 method for signature 'SRM' plotPeakArea(object, index, sampleName)plotPeakArea(object, index, sampleName) ## S4 method for signature 'SRM' plotPeakArea(object, index, sampleName)
object |
a SRM object |
index |
a numeric value of the transition index to plot |
sampleName |
a character string of |
a ggplot plot object
Plot Sample
plotSample(object, sampleName, polarity) ## S4 method for signature 'SRM' plotSample(object, sampleName, polarity)plotSample(object, sampleName, polarity) ## S4 method for signature 'SRM' plotSample(object, sampleName, polarity)
object |
a SRM object |
sampleName |
a character string of a valid |
polarity |
a character string of either |
a ggplot plot object
Plot SRM
plotSRM(object, index, type = "overlay") ## S4 method for signature 'SRM' plotSRM(object, index, type = "overlay")plotSRM(object, index, type = "overlay") ## S4 method for signature 'SRM' plotSRM(object, index, type = "overlay")
object |
a SRM object |
index |
a numeric value of the transition index to plot |
type |
a character string of either |
a ggplot plot object
Reduce detected peaks using a relative area threshold
reducePeaks(object, relative_area) ## S4 method for signature 'SRM' reducePeaks(object, relative_area = 0.05)reducePeaks(object, relative_area) ## S4 method for signature 'SRM' reducePeaks(object, relative_area = 0.05)
object |
a SRM object |
relative_area |
a numeric value between 0 and 1, for the threshold of relative peak area |
a SRM object
Remove Sample
removeSample(object, sampleName) ## S4 method for signature 'SRM' removeSample(object, sampleName)removeSample(object, sampleName) ## S4 method for signature 'SRM' removeSample(object, sampleName)
object |
a SRM object |
sampleName |
a character string of a |
a SRM object
Keep Transitions
removeTransitions(object, index_out) ## S4 method for signature 'SRM' removeTransitions(object, index_out = c())removeTransitions(object, index_out) ## S4 method for signature 'SRM' removeTransitions(object, index_out = c())
object |
a SRM object |
index_keep |
a numeric vector of transition index to remove |
a SRM object
show-SRM
## S4 method for signature 'SRM' show(object)## S4 method for signature 'SRM' show(object)
object |
a SRM object |
Smooth Chromatograms
smoothChrom(object, cf) ## S4 method for signature 'SRM' smoothChrom(object, cf)smoothChrom(object, cf) ## S4 method for signature 'SRM' smoothChrom(object, cf)
object |
a SRM object |
cf |
matrix, a coefficient matrix generated by MsCoreUtils::coefMA or MsCoreUtils::coefWMA |
a SRM object
A S4 class to store single reaction monitoring (SRM) mass spectrometry (MS) data
metaa tibble of a minimal amount of meta data.
transitionsa tibble of all transitions names
chromsa tibble of retention time (rt) and intensity (int) values for all imported SRM chromatograms
peaksa tibble of detected peaks
groupsa tibble of peak information for user defined groups
headera tibble of formatted header data from mzR::header()
List all transitions
transitions(object) ## S4 method for signature 'SRM' transitions(object)transitions(object) ## S4 method for signature 'SRM' transitions(object)
object |
a |